      Subroutine cossza(glat,glon,sbsllat,sbsllon,csza)
C  Computes cosine of solar zenith angle from geographic coordinates of point
C   in question and of subsolar point.
C  940730 A. D. Richmond, NCAR

C   Inputs:
C    glat = geographic latitude of point (degrees)
C    glon = geographic longitude of point (degrees)
C    sbsllat = geographic latitude of subsolar point (degrees)
C    sbsllon = geographic longitude of subsolar point (degrees)
C   Output:
C    csza = cosine of solar zenith angle

      PARAMETER (rtod=5.72957795130823E1,dtor=1.745329251994330E-2)

      ct = sin(glat*dtor)
      st = sqrt(1. - ct*ct)
      cs = sin(sbsllat*dtor)
      ss = sqrt(1. - cs*cs)
      ang = (glon - sbsllon)*dtor
      csza = ct*cs + st*ss*cos(ang)
      return
      end
